Version 0.10.1 — Version 0.11.0.dev0

# Version 0.10.1

December 28, 2022

## Changelog

### Bug fixes

- Fix a regression in over-sampler where the string `minority` was rejected as an unvalid sampling strategy. #964 by Prakhyath Bhandary.

# Version 0.10.0

December 9, 2022

## Changelog

### Bug fixes

- Make sure that `Substitution` is working with `python -OO` that replace `__doc__` by `None`. #953 bu Guillaume Lemaitre.

### Compatibility

- Maintenance release for be compatible with scikit-learn >= 1.0.2. #946, #947, #949 by Guillaume Lemaitre.

- Add support for automatic parameters validation as in scikit-learn >= 1.2. #955 by Guillaume Lemaitre.

- Add support for `feature_names_in_` as well as `get_feature_names_out` for all samplers. #959 by Guillaume Lemaitre.

### Deprecation

- The parameter `n_jobs` has been deprecated from the classes `ADASYN`, `BorderlineSMOTE`, `SMOTE`, `SMOTENC`, `SMOTEN`, and `SVMSMOTE`. Instead, pass a nearest neighbors estimator where `n_jobs` is set. #887 by Guillaume Lemaitre.

- The parameter `base_estimator` is deprecated and will be removed in version 0.12. It is impacted the following classes: `BalancedBaggingClassifier`, `EasyEnsembleClassifier`, `RUSBoostClassifier`. #946 by Guillaume Lemaitre.

### Enhancements

- Add support to accept compatible `NearestNeighbors` objects by only duck-typing. For instance, it allows to accept cuML instances. #858 by NV-jpt and Guillaume Lemaitre.